@@ -115,7 +115,7 @@ def set_chrome_options():
     options.add_argument("--allow-insecure-localhost")
     options.add_argument('ignore-certificate-errors')
     options.add_experimental_option('excludeSwitches', ['enable-logging'])
-    options.add_argument("--headless")
+    # options.add_argument("--headless")
     preferences = {
         "profile.default_content_setting_values.automatic_downloads": 1,
         "download.default_directory": output_folder,
