@@ -285,7 +285,7 @@ def get_number_of_elements_replace_value(self, locator, value, elem_name, wait_t
     return actual_count
 
 
-def get_element_text(self, locator, elem_name, wait_time=None):
+def get_element_text(locator, elem_name, wait_time=None):
     """Allow to get the text of a element using selenium
 
     Args:
